@@ -9,7 +9,9 @@
 iDeclareType(DocumentWidget)
 
 iDeclareType(Root)   
+iDeclareNotifyFunc(Root, ArrangementChanged)
 iDeclareNotifyFunc(Root, VisualOffsetsChanged)
+iDeclareAudienceGetter(Root, arrangementChanged)
 iDeclareAudienceGetter(Root, visualOffsetsChanged)
 
 struct Impl_Root {
@@ -21,6 +23,7 @@ struct Impl_Root {
     int        loadAnimTimer;
     iBool      didAnimateVisualOffsets;
     iBool      didChangeArrangement;
+    iAudience *arrangementChanged;
     iAudience *visualOffsetsChanged; /* called after running tickers */
     iColor     tmPalette[tmMax_ColorId]; /* theme-specific palette */
 };
@@ -34,8 +37,8 @@ void        createUserInterface_Root            (iRoot *);
 void        setCurrent_Root                     (iRoot *);
 iRoot *     current_Root                        (void);
 iRoot *     get_Root                            (void); /* assert != NULL */
-iAnyObject *findWidget_Root                     (const char *id); /* under current Root */
-iDocumentWidget *findDocument_Root              (const iRoot *, const iString *url);
+iAnyObject *        findWidget_Root             (const char *id); /* under current Root */
+iDocumentWidget *   findDocument_Root           (const iRoot *, const iString *url);
 
 iPtrArray * onTop_Root                          (iRoot *);
 void        destroyPending_Root                 (iRoot *);
@@ -44,6 +47,7 @@ void        updateMetrics_Root                  (iRoot *);
 void        updatePadding_Root                  (iRoot *); /* TODO: is part of metrics? */
 void        dismissPortraitPhoneSidebars_Root   (iRoot *);
 void        showToolbar_Root                    (iRoot *, iBool show);
+void        enableToolbar_Root                  (iRoot *, iBool enable);
 void        updateToolbarColors_Root            (iRoot *);
 void        showOrHideNewTabButton_Root         (iRoot *);
 
